import AuthManager from './auth-manager'
import { AxiosInstance } from 'axios'
import * as Pushy from 'pushy-electron'
import * as config from '../config.json'
import log from 'electron-log'
import { createClient } from './client'

type Message = {
  title: string
  reader: string
  token: string
}

export default class NotificationsManager {
  private client: AxiosInstance

  constructor(private authManager: AuthManager) {
    this.client = createClient(authManager)

    this.client.interceptors.request.use((config) => {
      const user = this.authManager.getCurrentUser()

      if (user !== null) {
        config.headers = {
          Authorization: `Bearer ${user.accessToken}`,
        }
      }

      return config
    })
  }

  async register(callback: (message: Message) => void) {
    log.info('[Push] Registering for push notifications')

    Pushy.listen()
    Pushy.setNotificationListener(callback)

    const deviceToken = await Pushy.register({ appId: config.PUSHY_APP_ID })

    this.authManager.onChange(async () => {
      await this.saveDeviceToken(deviceToken)
    })

    await this.saveDeviceToken(deviceToken)
  }

  private async saveDeviceToken(deviceToken: string): Promise<void> {
    const user = this.authManager.getCurrentUser()

    if (user !== null && !user.tfaMissing) {
      try {
        await this.client.post('/v1/notifications', {
          deviceToken,
        })
      } catch (e) {
        log.error(`[Push] Unable to save device token: ${e.message}`)
      }
    }
  }
}
