import React, { useState } from 'react'

type Props = {
  confirmTfa: (code: string) => Promise<void>,
}

const ConfirmTfaDialog = ({
  confirmTfa,
}: Props) => {
  const [code, setCode] = useState('')

  const [loading, setLoading] = useState(false)
  const [error, setError] = useState<string | null>(null)

  return (
    <div>
      {error && (
        <div>
          Error: {error}
        </div>
      )}
      <div>
        <label>
          Code:
          <input type="text" value={code} onChange={e => {
            setCode(e.target.value)
            setError(null)
          }} />
        </label>
      </div>
      <div>
        <button disabled={loading} onClick={async () => {
          try {
            setLoading(true)
            await confirmTfa(code)
          } catch (e) {
            setError(e)
            setLoading(false)
          }
        }}>
          {loading ? 'Loading...' : 'Confirm'}
        </button>
      </div>
    </div>
  )
}

export default ConfirmTfaDialog
