import React, { useEffect, useState } from 'react'
import CircularProgress from '@material-ui/core/CircularProgress';
import { EditKlinkDetails, KlinkDetails, ViewKlinkDetails } from '../../../common/types'
import KlinkDetailsView from '../KlinkDetails'
import { getKlinkToken } from './utils'
import ActionButtons from '../ActionButtons'
import { DeklinkInput } from './styles'

type Props = {
  readKlink: (token: string) => Promise<ViewKlinkDetails | EditKlinkDetails>
  editKlink: (token: string, klinkDetails: KlinkDetails) => Promise<void>
  close: () => void
}

const DeklinkDialog = ({ readKlink, editKlink, close }: Props) => {
  const [error, setError] = useState<string | null>(null)
  const [klinkReference, setKlinkReference] = useState('')
  const [klinkToken, setKlinkToken] = useState('')
  const [loading, setLoading] = useState(false)
  const [data, setData] = useState<ViewKlinkDetails | EditKlinkDetails | null>(null)

  useEffect(() => {
    try {
      const klinkUrl = new URL(klinkReference)
      const klinkToken = getKlinkToken(klinkUrl) || ''

      setKlinkToken(klinkToken)
    } catch (e) {
      setKlinkToken(klinkReference)
    }
  }, [klinkReference])

  const deklink = async () => {
    setLoading(true)
    try {
      setData(await readKlink(klinkToken))
    } catch (error) {
      setError(error)
    } finally {
      setLoading(false)
    }
  }

  return (
    <>
      <div>
        <div>
          <h3>Enter your Klink in field below:</h3>
          <DeklinkInput
            value={klinkReference}
            onChange={(e) => {
              setKlinkReference(e.target.value)
              setData(null)
              setError(null)
            }}
            variant="outlined"
            size="small"
          />
        </div>
        <ActionButtons
          loading={loading}
          actionName={loading ? 'Loading...' : 'Deklink'}
          action={deklink}
          close={close}
        />
        {error && <div>Error: {error}</div>}
        {data && (
          <KlinkDetailsView
            data={data}
            editKlink={(data) => editKlink(klinkToken, data)}
            close={close}
          />
        )}
        {loading && <CircularProgress />}
      </div>
    </>
  )
}

export default DeklinkDialog
