import React, { useEffect, useState } from 'react'
import Button from '@material-ui/core/Button'
import { useHistory } from 'react-router-dom'
import { EditKlinkDetails } from '../../../common/types'
import { Contact } from '../../types'
import { getContactsWithPhones } from '../ContactsRepository'
import { StyledTableCell, StyledTableRow } from './styles'

type Props = {
  klink: EditKlinkDetails
}

const NO_CONTACTS_STRING = '-'
const CONTACTS_SEPARATOR = ', '

export const KlinkTableRow = ({ klink }: Props) => {
  const history = useHistory()

  const [contacts, setContacts] = useState<Contact[]>([])
  const contactReferences = contacts.map((contact) => contact.name || contact.phone)
  const contactsString = contactReferences.join(CONTACTS_SEPARATOR) || NO_CONTACTS_STRING

  useEffect(() => {
    getContactsWithPhones(klink.sharedWith).then(setContacts)
  }, [klink.sharedWith])

  return (
    <StyledTableRow>
      <StyledTableCell>{klink.url}</StyledTableCell>
      <StyledTableCell align="right">{contactsString}</StyledTableCell>
      <StyledTableCell align="right">
        {klink.notifications ? 'Enabled' : 'Disabled'}
      </StyledTableCell>
      <StyledTableCell align="right">
        <Button
          color="primary"
          variant="contained"
          style={{ color: 'white' }}
          onClick={() => history.push(`/klink/${klink.token}`)}
        >
          Edit
        </Button>
      </StyledTableCell>
    </StyledTableRow>
  )
}
